==> flyspray_0.9.6a.orig.tar.gz: flyspray-0.9.6/lang/it/admin.php <==
<?php

global $admin_text;
$admin_text = array (

'edituser'			=>	'Modifica utente',
'username'			=>	'Username',
'realname'			=>	'Nome vero',
'emailaddress'		=>	'Indirizzo e-mail',
'jabberid'			=>	'Jabber ID',
'notifytype'		=>	'Tipo di notifica',
'group'				=>	'Gruppo',
'accountenabled'	=>	'Utenza abilitata',
'updatedetails'		=>	'Aggiorna le informazioni',
'setglobally'		=>	'Questa opzione e\' stata impostata a livello globale.',

'usergroupmanage'	=>	'Gestione Utenti e Gruppi',
'newuser'			=>	'Registra un nuovo utente',
'newgroup'			=>	'Crea un nuovo gruppo',
'yes'				=>	'Si',
'no'				=>	'No',

'editgroup'			=>	'Modifica il gruppo',
'groupname'			=>	'Nome del gruppo',
'description'		=>	'Descrizione',
'admin'				=>	'Amministratore del gruppo',
'opennewtasks'		=>	'Apri un nuovo task',
'modifytasks'		=>	'Modifica un task esistente',
'addcomments'		=>	'Aggiungi commenti',
'attachfiles'		=>	'Aggiungi file',
'vote'				=>	'Vota',
'groupenabled'		=>	'I membri possono fare login',

'tasktypelist'		=>	'Lista dei tipi di task',
'categorylist'		=>	'Lista delle categorie',
'oslist'			=>	'Lista dei sistemi operativi',
'resolutionlist'	=>	'Lista delle soluzioni',
'versionlist'		=>	'Lista delle versioni',
'severitylist'		=>	'Lista delle gravita\'',
'listnote'			=>	'Nota:  Disabilitando il box "mostra" potrebbe alterare alcuni task quando in modalita\' modifica.  La modifica del campo "Nome" cambiera\' tutti i task con quel nome.',
'name'				=>	'Nome',
'order'				=>	'Ordinamento',
'back'				=>	'Sfondo',
'text'				=>	'Testo',
'highlight'			=>	'In evidenza',
'show'				=>	'Mostra',
'owner'				=>	'Proprietario',
'selectowner'		=>	'Seleziona il proprietario',
'update'			=>	'Aggiorna',
'addnew'			=>	'Aggiungi nuovo',

'flysprayprefs'		=>	'Preferenze di Flyspray',
'projecttitle'		=>	'Titolo del Progetto',
'baseurl'			=>	'URL base per questa installazione',
'replyaddress'		=>	'Indirizzo e-mail di reply per le notifiche',
'themestyle'		=>	'Tema / Stile',
'language'			=>	'Linguaggio',
'anonview'			=>	'Consenti agli utenti anonimi di visualizzare i task',
'allowanon'			=>	'Consenti agli utenti anonimi di creare nuovi task',
'never'				=>	'Mai',
'anonymously'		=>	'In modo anonimo',
'afterregister'		=>	'Solo dopo essere stati registrati',
'spamproof'			=>	'Abilita il codice di conferma per le nuove registrazioni utenti',
'anongroup'			=>	'Gruppo per i nuovi utenti',
'groupassigned'		=>	'Ai membri di questo gruppo possono essere assegnati dei task',
'forcenotify'		=>	'Forza la notifica dei task come',
'none'				=>	'Non mandare mai',
'userchoose'		=>	'Lascia scegliere l\'utente',
'email'				=>	'e-mail',
'jabber'			=>	'Jabber',
'defaultcatowner'	=>	'Default category owner',
'noone'				=>	'Nessuna',
'jabbernotify'		=>	'Notifiche Jabber',
'jabberserver'		=>	'Server',
'jabberport'		=>	'Port',
'jabberuser'		=>	'Account Username',
'jabberpass'		=>	'Account Password',
'saveoptions'		=>	'Salva le opzioni',

'editcomment'		=>	'Modifica il Commento',
'commentby'			=>	'Commento a cura di',
'saveeditedcomment'	=>	'Salva il commento modificato',

// Added in version 0.9.5

'projectprefs'		=>	'Preferenze del progetto',
'defaultproject'	=>	'Progetto predefinito',
'projectlists'		=>	'Lista di progetti',
'showlogo'			=>	'Mostra titolo logo immagine',
'intromessage'		=>	'Messaggio di introduzione',
'isactive'			=>	'Il progetto e\' attivo',
'createproject'		=>	'Crea un nuovo progetto',

// Added in version 0.9.6

'nopermission'		=>  'Non hai il permesso di usare questa pagina.',
'listordertip'		=>  'L\'ordine con cui questi dati appariranno nella lista',
'listshowtip'		=>	'Mostra questo dato nella lista',
'categoryownertip'	=>  'Questa persona ricevera\' una notifica quando verra\' aperto un task in questa categoria',
'categoryparenttip'	=>	'La categoria padre sotto cui cadra\' questa nuova',
'notsubcategory'	=>	'Nessuna - e\'una categoria primaria',
'showinlineimages'	=>  'Mostra gli allegati immagine inline',
'dateformat'		=>	'Formato date',
'dateformat_extended' => 'Formato date esteso',
'subcategoryof'		=>	'Sottocategoria di',
'visiblecolumns'	=>	'Colonne mostrate nella lista task',
'tense'			=>	'Tempo',
'listtensetip'		=>	'Passato, presente o futuro',
'past'			=>	'Passato',
'present'		=>	'Presente',
'future'		=>	'Futuro',
'changepass'	=>      'Cambia password',
'confirmpass'	=>      'Conferma password',
);
?>

==> flyspray_0.9.7.orig.tar.gz: flyspray-0.9.7/lang/it/admin.php <==
<?php

global $admin_text;
$admin_text = array (

'edituser'			=>	'Modifica utente',
'username'			=>	'Username',
'realname'			=>	'Nome vero',
'emailaddress'		=>	'Indirizzo e-mail',
'jabberid'			=>	'Jabber ID',
'notifytype'		=>	'Tipo di notifica',
'group'				=>	'Gruppo',
'accountenabled'	=>	'Utenza abilitata',
'updatedetails'		=>	'Aggiorna le informazioni',
'setglobally'		=>	'Questa opzione e\' stata impostata a livello globale.',

'usergroupmanage'	=>	'Gestione Utenti e Gruppi',
'newuser'			=>	'Registra un nuovo utente',
'newgroup'			=>	'Crea un nuovo gruppo',
'yes'				=>	'Si',
'no'				=>	'No',

'editgroup'			=>	'Modifica il gruppo',
'groupname'			=>	'Nome del gruppo',
'description'		=>	'Descrizione',
'admin'				=>	'Amministratore del gruppo',
'opennewtasks'		=>	'Apri un nuovo task',
'modifytasks'		=>	'Modifica un task esistente',
'addcomments'		=>	'Aggiungi commenti',
'attachfiles'		=>	'Aggiungi file',
'vote'				=>	'Vota',
'groupenabled'		=>	'I membri possono fare login',

'tasktypelist'		=>	'Lista dei tipi di task',
'categorylist'		=>	'Lista delle categorie',
'oslist'			=>	'Lista dei sistemi operativi',
'resolutionlist'	=>	'Lista delle soluzioni',
'versionlist'		=>	'Lista delle versioni',
'severitylist'		=>	'Lista delle gravita\'',
'listnote'			=>	'Nota:  Disabilitando il box "mostra" potrebbe alterare alcuni task quando in modalita\' modifica.  La modifica del campo "Nome" cambiera\' tutti i task con quel nome.',
'name'				=>	'Nome',
'order'				=>	'Ordinamento',
'back'				=>	'Sfondo',
'text'				=>	'Testo',
'highlight'			=>	'In evidenza',
'show'				=>	'Mostra',
'owner'				=>	'Proprietario',
'selectowner'		=>	'Seleziona il proprietario',
'update'			=>	'Aggiorna',
'addnew'			=>	'Aggiungi nuovo',

'flysprayprefs'		=>	'Preferenze di Flyspray',
'projecttitle'		=>	'Titolo del Progetto',
'baseurl'			=>	'URL base per questa installazione',
'replyaddress'		=>	'Indirizzo e-mail di reply per le notifiche',
'themestyle'		=>	'Tema / Stile',
'language'			=>	'Linguaggio',
'anonview'			=>	'Consenti agli utenti anonimi di visualizzare i task',
'allowanon'			=>	'Consenti agli utenti anonimi di creare nuovi task',
'never'				=>	'Mai',
'anonymously'		=>	'In modo anonimo',
'afterregister'		=>	'Solo dopo essere stati registrati',
'spamproof'			=>	'Abilita il codice di conferma per le nuove registrazioni utenti',
'anongroup'			=>	'Gruppo per i nuovi utenti',
'groupassigned'		=>	'Ai membri di questo gruppo possono essere assegnati dei task',
'forcenotify'		=>	'Forza la notifica dei task come',
'none'				=>	'Non mandare mai',
'userchoose'		=>	'Lascia scegliere l\'utente',
'email'				=>	'e-mail',
'jabber'			=>	'Jabber',
'defaultcatowner'	=>	'Default category owner',
'noone'				=>	'Nessuna',
'jabbernotify'		=>	'Notifiche Jabber',
'jabberserver'		=>	'Server',
'jabberport'		=>	'Port',
'jabberuser'		=>	'Account Username',
'jabberpass'		=>	'Account Password',
'saveoptions'		=>	'Salva le opzioni',

'editcomment'		=>	'Modifica il Commento',
'commentby'			=>	'Commento a cura di',
'saveeditedcomment'	=>	'Salva il commento modificato',

// Added in version 0.9.5

'projectprefs'		=>	'Preferenze del progetto',
'defaultproject'	=>	'Progetto predefinito',
'projectlists'		=>	'Lista di progetti',
'showlogo'			=>	'Mostra titolo logo immagine',
'intromessage'		=>	'Messaggio di introduzione',
'isactive'			=>	'Il progetto e\' attivo',
'createproject'		=>	'Crea un nuovo progetto',

// Added in version 0.9.6

'nopermission'		=>  'Non hai il permesso di usare questa pagina.',
'listordertip'		=>  'L\'ordine con cui questi dati appariranno nella lista',
'listshowtip'		=>	'Mostra questo dato nella lista',
'categoryownertip'	=>  'Questa persona ricevera\' una notifica quando verra\' aperto un task in questa categoria',
'categoryparenttip'	=>	'La categoria padre sotto cui cadra\' questa nuova',
'notsubcategory'	=>	'Nessuna - e\'una categoria primaria',
'showinlineimages'	=>  'Mostra gli allegati immagine inline',
'dateformat'		=>	'Formato date',
'dateformat_extended' => 'Formato date esteso',
'subcategoryof'		=>	'Sottocategoria di',
'visiblecolumns'	=>	'Colonne mostrate nella lista task',
'tense'			=>	'Tempo',
'listtensetip'		=>	'Passato, presente o futuro',
'past'			=>	'Passato',
'present'		=>	'Presente',
'future'		=>	'Futuro',
'changepass'	=>      'Cambia password',
'confirmpass'	=>      'Conferma password',

// Added in version 0.9.7
                     
'projectmanager'	=>	'Project Manager',
'viewtasks'		=>	'Visualizza task',
'opennewtasks'		=>	'Apri nuovo task',
'modifyowntasks'	=>	'Modifica un proprio task',
'modifyalltasks'	=>	'Modifica task che non sono propri dell\'utente',
'viewcomments'		=>	'Visualizza commenti',
'editcomments'		=>	'Modifica commenti',
'deletecomments'	=>	'Cancella commenti',
'viewattachments'	=>	'Visualizza attachment',
'createattachments'	=>	'Crea attachment',
'deleteattachments'	=>	'Cancella attachment',
'viewhistory'		=>	'Visualizza lo storico',
'closeowntasks'		=>	'Chiudi un proprio task',
'closeothertasks'	=>	'Chiudi task che non sono propri dell\'utente',
'assigntoself'		=>	'Assegnati i task se non sono gia assegnati',
'assignotherstoself'	=>	'Assegnati i task degli altri',
'viewreports'		=>	'Visualizza i report',
'othersview'		=>	'Permetti a chiunque di visualizzare questo progetto',
'usergroups'		=>	'Utenti e gruppi',
'globalgroup'		=>	'Gruppo globale',  // Singular 
'globalgroups'		=>	'Gruppi globali', // Plural
'defaultglobalgroup'    =>      'Gruppo globale predefinito per i nuovi utenti',
'addtogroup'		=>	'Aggiungi al gruppo',
'moveuserstogroup'	=>	'Sposta gli utenti al gruppo',
'nogroup'		=>	'Nessun gruppo - elimina dal progetto',
'pendingrequests'       =>      'Richieste amministrative incomplete',
'eventdesc'             =>      'Descrizione dell\'evento',
'requestedby'           =>      'Richiesto da',
'daterequested'         =>      'Data della richiesta',
'closetask'             =>      'Chiudi Task',
'reopentask'            =>      'Riapri Task',
'applymember'           =>      'Richiedi l\'accesso al progetto',
'forcurrentproj'        =>      'Per il progetto corrente',
'lostpw'		=>	'Recupero password perse',
'lostpwexplain'		=>	'Inserisci il nome utente per inviarti un link per il cambio password. Il link sara\' inviato all\'indirizzo di notifica nel tuo profilo.',
'sendlink'		=>	'Invia link',
'savenewpass'           =>      'Memorizza la nuova password',
'badmagic'              =>      'Non è una chiave magica valida! Sei sicuro di averla presa dal tuo messaggio di notifica?',
'anonreg'               =>      'Permetti la registrazione di nuovi utenti',
'allowanonopentask'     =>      'Permetti agli utenti anonimi di aprire task',
'editglobalgroup'       =>      'Modifica i gruppi globali',
'editgroupforproj'      =>      'Modifica i gruppi per progetto',
'notshownforadmin'      =>      'I permessi del gruppo admin non vengono mostrati.  Non hai bisogno di modificarli.',
'general'               =>      'Generale',
'userregistration'      =>      'User Registrazione utenti',
'notifications'         =>      'Notifiche',
'resetoptions'          =>      'Annulla Opzioni',


                     
);
?>
